@@ -338,6 +338,64 @@ impl From<ProjectHook> for Hook {
     }
 }
 
+/// Reponse of a project variable
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct ProjectVariable {
+    /// The key
+    pub key: String,
+    // The variable type
+    pub variable_type: String,
+    /// The value
+    pub value: String,
+    /// Flag if its protected
+    pub protected: bool,
+    /// Flag if its masked
+    pub masked: bool,
+    /// Environment scope
+    pub environment_scope: String,
+}
+
+/// Reponse of a project variable
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct ProtectedTagAccessLevel {
+    /// The access level id
+    pub access_level: u64,
+    // The access level
+    pub access_level_description: String,
+}
+
+/// Reponse of a project variable
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct ProtectedTag {
+    /// The name or wildcard
+    pub name: String,
+    // The access level
+    pub create_access_levels: Vec<ProtectedTagAccessLevel>,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct ReleaseTag {
+    // The release tag name
+    pub tag_name: String,
+    // The release tag description
+    pub description: String,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct Tag {
+    // Commit message
+    pub commit: RepoCommit,
+    // Release tag
+    pub release: Option<ReleaseTag>,
+    // Tag name
+    pub name: String,
+    // Target sha
+    pub target: String,
+    pub message: Option<String>,
+    // Is tag protected
+    pub protected: bool,
+}
+
 impl_id!(ProjectId, "Type-safe project ID.");
 
 /// Basic project information.
@@ -866,10 +924,11 @@ pub struct RepoBranch {
     pub default: Option<bool>,
 }
 
+#[allow(clippy::upper_case_acronyms)]
 #[derive(Deserialize, Debug, Clone)]
 pub struct PRBAccessLevel {
-    access_level: u64,
-    access_level_description: String,
+    pub access_level: u64,
+    pub access_level_description: String,
 }
 
 /// A protected branch on a repository
@@ -878,7 +937,7 @@ pub struct ProtectedRepoBranch {
     pub name: String,
     pub push_access_levels: Vec<PRBAccessLevel>,
     pub merge_access_levels: Vec<PRBAccessLevel>,
-    pub code_owner_approval_required: bool,
+    pub code_owner_approval_required: Option<bool>,
 }
 
 /// The ID of a git object.
@@ -934,7 +993,8 @@ pub struct RepoCommit {
     /// The summary of the commit.
     pub title: String,
     /// The commit ID of the parents of the commit.
-    pub parent_ids: Vec<ObjectId>,
+    /// Can be null on projects/:id/repository/branches call
+    pub parent_ids: Option<Vec<ObjectId>>,
     /// The commit author's name.
     pub author_name: String,
     /// The commit author's email address.
@@ -952,6 +1012,24 @@ pub struct RepoCommit {
     pub message: String,
 }
 
+/// A commit in a project.
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct MergeRequestCommit {
+    /// The ID of the commit.
+    pub id: ObjectId,
+    /// The short ID of the commit.
+    pub short_id: ObjectId,
+    /// The summary of the commit.
+    pub title: String,
+    /// The commit author's name.
+    pub author_name: String,
+    /// The commit author's email address.
+    pub author_email: String,
+    pub created_at: DateTime<Utc>,
+    /// The full commit message.
+    pub message: String,
+}
+
 /// Stats about a commit.
 #[derive(Serialize, Deserialize, Debug, Clone, Copy)]
 pub struct RepoCommitStats {
@@ -1515,6 +1593,9 @@ impl_id!(
 /// The status of the possible merge for a merge request.
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq)]
 pub enum MergeStatus {
+    /// The merge request has just been created.
+    #[serde(rename = "preparing")]
+    Preparing,
     /// The merge request has not been checked yet.
     #[serde(rename = "unchecked")]
     Unchecked,
@@ -1606,7 +1687,7 @@ pub struct MergeRequest {
     /// The reviewers of the merge request.
     pub reviewers: Option<Vec<UserBasic>>,
     /// The ID of the project hosting the source branch.
-    pub source_project_id: ProjectId,
+    pub source_project_id: Option<ProjectId>,
     /// The ID of the project hosting the target branch.
     pub target_project_id: ProjectId,
     /// The labels attached to the merge request.
@@ -1668,6 +1749,8 @@ pub struct MergeRequest {
     pub web_url: String,
     /// Basic pipeline information for the MR.
     pub pipeline: Option<PipelineBasic>,
+    /// Whether the user doesn't have any commits in the repo, denoting the first contribution.
+    pub first_contribution: Option<bool>,
 }
 
 /// A merge request with changes.
@@ -1714,7 +1797,7 @@ pub struct MergeRequestChanges {
     /// The reviewers of the merge request.
     pub reviewers: Option<Vec<UserBasic>>,
     /// The ID of the project hosting the source branch.
-    pub source_project_id: ProjectId,
+    pub source_project_id: Option<ProjectId>,
     /// The ID of the project hosting the target branch.
     pub target_project_id: ProjectId,
     /// The labels attached to the merge request.
@@ -1826,6 +1909,7 @@ impl From<MergeRequestChanges> for MergeRequest {
             user: Some(mr.user),
             web_url: mr.web_url,
             pipeline: mr.pipeline,
+            first_contribution: None,
         }
     }
 }
@@ -1878,6 +1962,8 @@ pub enum NoteType {
 /// The various types a note can have
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq)]
 pub enum DiscussionNoteType {
+    /// A note in a discussion
+    Note,
     /// A note in a standard discussion
     DiscussionNote,
     /// A note attached to a diff
@@ -2135,6 +2221,12 @@ pub enum StatusState {
     /// The check was created.
     #[serde(rename = "created")]
     Created,
+    /// The check is waiting for some other resource.
+    #[serde(rename = "waiting_for_resource")]
+    WaitingForResource,
+    /// The check is currently being prepared.
+    #[serde(rename = "preparing")]
+    Preparing,
     /// The check is queued.
     #[serde(rename = "pending")]
     Pending,
@@ -2156,6 +2248,9 @@ pub enum StatusState {
     /// The check is waiting for manual action.
     #[serde(rename = "manual")]
     Manual,
+    /// The check is scheduled to run at some point in time.
+    #[serde(rename = "scheduled")]
+    Scheduled,
 }
 
 /// A status of a commit.
